@@ -1,13 +1,13 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Календар",
     "%s has published the calendar »%s«" : "%s е публикувал календар »%s«",
     "Successfully sent email to " : "Успешно изпратен имейл до",
     "Hello," : "Здравейте, ",
     "We wanted to inform you that %s has published the calendar »%s«." : "Информираме ви, че%s е публикувал календара »%s«.",
     "Open »%s«" : "Отвори »%s«",
     "Cheers!" : "Поздрави!",
+    "Calendar" : "Календар",
     "A Calendar app for Nextcloud" : "Календар за Nextcloud",
     "Previous day" : "Вчера",
     "Previous week" : "Миналата седмица",
@@ -24,6 +24,7 @@ OC.L10N.register(
     "Edit name" : "Редактирай името",
     "Saving name …" : "Запазване...",
     "Edit color" : "Смени цвета",
+    "Saving color …" : "Запазване на цвета ...",
     "Copy private link" : "Копирай скритата връзка",
     "Download" : "Изтегляне",
     "Delete" : "Изтриване",
@@ -41,6 +42,7 @@ OC.L10N.register(
     "New calendar" : "Нов календар",
     "Import calendars" : "Импортиране на календари",
     "Filename" : "Име на файла",
+    "Calendar to import into" : "Избран календар за внасяне в",
     "Cancel" : "Отказ",
     "_Import calendar_::_Import calendars_" : ["Импортиране на календар","Импортиране на календари"],
     "Automatic" : "Автоматично",
@@ -49,20 +51,32 @@ OC.L10N.register(
     "Settings & import" : "Настройки и внасяне",
     "Notification" : "Известие",
     "Email" : "Имейл",
+    "On date" : "На дата",
+    "Edit time" : "Редакирай времето",
+    "Remove reminder" : "Премахни напомнянето",
+    "+ Add reminder" : "+ Добави напомняне",
     "_second_::_seconds_" : ["секунда","секунди"],
     "_minute_::_minutes_" : ["минута","минути"],
     "_hour_::_hours_" : ["час","часове"],
     "_day_::_days_" : ["ден","дни"],
     "_week_::_weeks_" : ["седмица","седмици"],
+    "No reminders yet" : "Няма напомняния",
     "Busy" : "Зает",
     "Unknown" : "Непознат",
     "Send e-mail" : "Изпрати имейл",
     "All day" : "Цял ден",
-    "from" : "от",
-    "to" : "до",
     "never" : "никога",
     "after" : "след",
+    "first" : "първи",
+    "third" : "трети",
+    "fourth" : "четвърти",
+    "fifth" : "пети",
+    "last" : "последен",
     "Repeat" : "Да се повтаря",
+    "Repeat every" : "Повтаряй всеки",
+    "On the" : "На",
+    "_month_::_months_" : ["месец","месеци"],
+    "_year_::_years_" : ["година","години"],
     "Monday" : "понеделник",
     "Summary" : "Резюме",
     "More" : "Още",
@@ -77,13 +91,18 @@ OC.L10N.register(
     "Close" : "Затвори",
     "Anniversary" : "Годишнина",
     "Week {number} of {year}" : "Седмица {number} от {year}",
+    "Does not repeat" : "Не се повтаря",
     "Daily" : "Всеки ден",
     "Weekly" : "Всяка седмица",
+    "Monthly" : "Месечно",
+    "Yearly" : "Годишно",
+    "_Every %n day_::_Every %n days_" : ["Всеки %n ден","Всеки %n дни"],
     "When shared show full event" : "При споделяне, показвай цялото събитие",
     "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
     "When shared hide this event" : "При споделяне, скривай това събитие",
     "Location" : "Местоположение",
     "Description" : "Описание",
+    "Add a description" : "Добави описание",
     "Status" : "Състояние",
     "Confirmed" : "Потвърдено",
     "Tentative" : "Несигурно",
