@@ -1,12 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Calendar",
     "%s has published the calendar »%s«" : "%s has published the calendar »%s«",
     "Hello," : "Hello,",
     "We wanted to inform you that %s has published the calendar »%s«." : "We wanted to inform you that %s has published the calendar »%s«.",
     "Open »%s«" : "Open »%s«",
     "Cheers!" : "Cheers!",
+    "Calendar" : "Calendar",
     "A Calendar app for Nextcloud" : "A Calendar app for Nextcloud",
     "Today" : "Today",
     "Day" : "Day",
@@ -27,8 +27,6 @@ OC.L10N.register(
     "Email" : "Email",
     "Unknown" : "Unknown",
     "All day" : "All day",
-    "from" : "from",
-    "to" : "to",
     "never" : "never",
     "after" : "after",
     "Repeat" : "Repeat",
@@ -58,6 +56,7 @@ OC.L10N.register(
     "Cancelled" : "Cancelled",
     "Categories" : "Categories",
     "Presentation" : "Presentation",
+    "Review" : "Review",
     "Office" : "Office",
     "Mail" : "Mail",
     "Play" : "Play",
