@@ -1,12 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Calendario",
     "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
     "Hello," : "Hola,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "¡Saludos!",
+    "Calendar" : "Calendario",
     "A Calendar app for Nextcloud" : "Una aplicación de Calendario para Nextcloud",
     "Today" : "Hoy",
     "Day" : "Día",
@@ -27,8 +27,6 @@ OC.L10N.register(
     "Email" : "Correo electrónico",
     "Unknown" : "Desconocido",
     "All day" : "Todo el día",
-    "from" : "de",
-    "to" : "para",
     "never" : "nunca",
     "after" : "después",
     "Repeat" : "Repetir",
