@@ -27,6 +27,7 @@ OC.L10N.register(
     "Show week numbers" : "הצגת מספרי שבועות",
     "Settings & import" : "הגדרות וייבוא",
     "Email" : "דוא״ל",
+    "Busy" : "עסוק",
     "Unknown" : "לא ידוע",
     "All day" : "כל היום",
     "never" : "לעולם לא",
@@ -48,6 +49,7 @@ OC.L10N.register(
     "Week {number} of {year}" : "שבוע {number} ב־{year}",
     "Daily" : "יומי",
     "Weekly" : "שבועי",
+    "Untitled event" : "אירוע ללא כותרת",
     "When shared show full event" : "כאשר משותף מציג אירוע מלא",
     "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
     "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
