@@ -91,6 +91,8 @@ OC.L10N.register(
     "Edit time" : "Breyta tíma",
     "Save time" : "Vista tíma",
     "Remove reminder" : "Fjarlægja áminningu",
+    "on" : "þann",
+    "at" : "klukkan",
     "+ Add reminder" : "+ Bæta við áminningu",
     "_second_::_seconds_" : ["sekúnda","sekúndur"],
     "_minute_::_minutes_" : ["mínúta","mínútur"],
@@ -98,7 +100,10 @@ OC.L10N.register(
     "_day_::_days_" : ["dagur","dagar"],
     "_week_::_weeks_" : ["vika","vikur"],
     "No reminders yet" : "Engar áminningar ennþá",
+    "Attendees, Resources and Rooms" : "Þáttakendur, tilföng og herbergi",
+    "Busy (tentative)" : "Upptekinn (með fyrirvara)",
     "Busy" : "Upptekinn",
+    "Out of office" : "Ekki á staðnum",
     "Unknown" : "Óþekkt",
     "{name} accepted your invitation." : "{name} hefur samþykkt boð þitt.",
     "{name} accepted {organizerName}'s invitation." : "{name} hefur samþykkt boð frá {organizerName}.",
@@ -146,6 +151,8 @@ OC.L10N.register(
     "Public calendar does not exist" : "Opinbert dagatal er ekki til",
     "Maybe the share was deleted or has expired?" : "Hugsanlega hefur sameigninni verið eytt eða hún sé útrunnin?",
     "Please select a timezone:" : "Veldu tímabelti:",
+    "Pick a time" : "Veldu tíma",
+    "Pick a date" : "Veldu dagsetningu",
     "Select Date" : "Veldu dag",
     "Personal" : "Persónulegt",
     "Delete this occurrence" : "Eyða þessu tilviki",
