@@ -1,7 +1,6 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "カレンダー",
     "User-Session unexpectedly expired" : "ユーザーセッションが予期せず期限切れになりました",
     "Provided email-address is not valid" : "メールアドレスが有効ではありません",
     "%s has published the calendar »%s«" : "%sをカレンダー »%s«に登録しました",
@@ -11,6 +10,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "%sがカレンダー»%s«に登録されましたのでお知らせします。",
     "Open »%s«" : "»%s«を開く",
     "Cheers!" : "それでは！",
+    "Calendar" : "カレンダー",
     "A Calendar app for Nextcloud" : "NextCloudのカレンダーアプリ",
     "Previous day" : "前日",
     "Previous week" : "前週",
@@ -72,7 +72,6 @@ OC.L10N.register(
     "New calendar" : "新しいカレンダー",
     "Creating calendar …" : "カレンダーを作成中 …",
     "New calendar with task list" : "タスクリスト付きの新しいカレンダー",
-    "New subscription from link" : "リンクから新たに購読",
     "Creating subscription …" : "購読を作成中 …",
     "An error occurred, unable to create the calendar." : "エラーが発生したため、カレンダーを作成できません。",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "有効なリンクを入力してください（http:// や https:// 、webcal:// または webcals:// のいずれかで始まる必要があります）",
@@ -138,8 +137,6 @@ OC.L10N.register(
     "Event title" : "イベントタイトル",
     "All day" : "終日",
     "Can not modify all-day setting for events that are part of a recurrence-set." : "繰り返しの一部であるイベントの終日設定を変更することはできません。",
-    "from" : "差出人",
-    "to" : "宛先",
     "from {startDate}" : "{startDate}から",
     "from {startDate} at {startTime}" : "{startDate}の{startTime}から",
     "to {endDate}" : "{endDate}まで",
@@ -189,12 +186,15 @@ OC.L10N.register(
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
     "Location" : "場所",
+    "Add a location" : "住所を追加",
     "Description" : "説明",
+    "Add a description" : "説明を追加",
     "Status" : "ステータス",
     "Confirmed" : "確認済み",
     "Tentative" : "暫定的",
     "Cancelled" : "キャンセル済",
     "Categories" : "カテゴリ",
+    "Search or add categories" : "カテゴリを検索または追加",
     "Add this as a new category" : "これを新しいカテゴリーとして追加",
     "Meditation" : "座禅",
     "Relaxing" : "休暇",
@@ -209,6 +209,7 @@ OC.L10N.register(
     "Brainstorm" : "会議",
     "Baseball" : "野球",
     "Meet" : "打ち合わせ",
+    "Review" : "レビュー",
     "Office" : "オフィス",
     "Party" : "パーティー",
     "Celebration" : "祝",
