@@ -123,6 +123,7 @@ OC.L10N.register(
     "No attendees yet" : "Сè уште нема присутни",
     "(organizer)" : "(organizer)",
     "To send out invitations and handle responses,  [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
+    "Remove color" : "Одстрани боја",
     "Event title" : "Наслов на настанот",
     "All day" : "Сите денови",
     "from {startDate}" : "од {startDate}",
@@ -156,6 +157,8 @@ OC.L10N.register(
     "Public calendar does not exist" : "Јавниот календар не постои",
     "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
     "Please select a timezone:" : "Изберете временска зона:",
+    "Pick a time" : "Избери време",
+    "Pick a date" : "Избери датум",
     "Select Date" : "Избери датум",
     "from {formattedDate}" : "од {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
@@ -238,6 +241,7 @@ OC.L10N.register(
     "Search or add categories" : "Барај или додади категории",
     "Add this as a new category" : "Додади како нова категорија",
     "Custom color" : "Прилагодена боја",
+    "Chat room for event" : "Соба за разговор за настанот",
     "Imported {filename}" : "Импортирано {filename}",
     "Meditation" : "Медитација",
     "Relaxing" : "Релаксирање",
