@@ -7,6 +7,10 @@ OC.L10N.register(
     "Open »%s«" : "Abrir »%s«",
     "Cheers!" : "Parabéns!",
     "Calendar" : "Calendário",
+    "Previous day" : "Dia anterior",
+    "Previous week" : "Semana anterior",
+    "Previous month" : "Mês anterior",
+    "Next day" : "Dia seguinte",
     "Today" : "Hoje",
     "Day" : "Dia",
     "Week" : "Semana",
@@ -16,6 +20,7 @@ OC.L10N.register(
     "Share link" : "Partilhar hiperligação",
     "Delete share link" : "Apagar hiperligação de partilha",
     "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
+    "No users or groups" : "Sem utilizadores ou grupos",
     "can edit" : "pode editar",
     "New calendar" : "Novo calendário",
     "Filename" : "Nome do ficheiro",
@@ -35,6 +40,7 @@ OC.L10N.register(
     "More" : "Mais",
     "Save" : "Guardar",
     "Update" : "Atualizar",
+    "Select Date" : "Escolha a data",
     "Personal" : "Pessoal",
     "Details" : "Detalhes",
     "Attendees" : "Participantes",
