@@ -1,22 +1,45 @@
 OC.L10N.register(
     "calendar",
     {
+    "Provided email-address is not valid" : "Adresa de email furnizată este invalidă",
     "%s has published the calendar »%s«" : "%sa publicat calendarul »%s«",
+    "Unexpected error sending email. Please contact your administrator." : "Eroare neașteptată la trimiterea emailului. Vă rog contactați-vă administratorul.",
+    "Successfully sent email to " : "Email trimis cu succes la ",
     "Hello," : "Salut,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Vă informăm că %sa publicat calendarul »%s«.",
     "Open »%s«" : "Accesează »%s«",
     "Cheers!" : "Noroc!",
     "Calendar" : "Calendar",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
+    "Previous day" : "Ziua anterioară",
+    "Previous week" : "Săptămâna anterioară",
+    "Previous month" : "Luna anterioară",
+    "Next day" : "Ziua următoare",
+    "Next week" : "Saptămâna următoare",
+    "Next month" : "Luna următoare",
+    "+ New event" : "+ Eveniment nou",
     "Today" : "Astăzi",
     "Day" : "Zi",
     "Week" : "Săptămâna",
     "Month" : "Luna",
+    "Untitled calendar" : "Calendar nedenumit",
+    "Edit name" : "Modifică numele",
+    "Saving name …" : "Se salvează numele ...",
+    "Edit color" : "Modifică culoarea",
+    "Saving color …" : "Se salvează culoarea  ...",
+    "Copy private link" : "Copiază link privat",
     "Download" : "Descarcă",
+    "Unshare from me" : "Anulare partajarea cu mine",
     "Delete" : "Șterge",
     "Share link" : "Partajază legătură",
+    "Publish calendar" : "Publică calendarul",
+    "Publishing calendar" : "Se publică calendarul",
+    "Copy public link" : "Copiză link-ul public",
+    "Copied code" : "Codul a fost copiat",
+    "Could not copy code" : "Nu sa putut copia codul",
     "Delete share link" : "Șterge linkul partajat",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
+    "No users or groups" : "Nu sunt utilizatori sau grupuri",
     "can edit" : "poate edita",
     "New calendar" : "Calendar nou",
     "Filename" : "Nume fișier",
