@@ -1,12 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
-    "Calendar" : "Kalendar",
     "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
     "Hello," : "Përshëndetje,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
     "Open »%s«" : "Hap »%s«",
     "Cheers!" : "Gëzuar!",
+    "Calendar" : "Kalendar",
     "Today" : "Sot",
     "Day" : "Ditë",
     "Week" : "Javë",
@@ -26,8 +26,6 @@ OC.L10N.register(
     "Email" : "Emaili",
     "Unknown" : "I/E panjohur",
     "All day" : "Gjithë ditën",
-    "from" : "nga",
-    "to" : "për",
     "never" : "kurrë",
     "after" : "pas",
     "Repeat" : "Përsërite",
