@@ -2,32 +2,26 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "يىلنامە",
-    "Share Calendar" : "يىلنامە ھەمبەھىر",
-    "group" : "گۇرۇپپا",
-    "Attendees" : "قاتناشقۇچىلار",
-    "Repeating" : "تەكرارلاش",
-    "None" : "يوق",
-    "never" : "ھەرگىز",
-    "Title of the Event" : "ھادىسە ماۋزۇسى",
+    "Today" : "بۈگۈن",
+    "Week" : "ھەپتە",
+    "Month" : "ئاي",
+    "Download" : "چۈشۈر",
     "Delete" : "ئۆچۈر",
+    "Share link" : "Share link",
+    "New calendar" : "يېڭى يىلنامە",
     "Cancel" : "ۋاز كەچ",
-    "Create" : "قۇر",
+    "Email" : "تورخەت",
+    "never" : "ھەرگىز",
+    "Repeat" : "قايتىلا",
+    "Monday" : "دۈشەنبە",
+    "More" : "تېخىمۇ كۆپ",
+    "Save" : "ساقلا",
     "Update" : "يېڭىلا",
+    "Personal" : "شەخسىي",
+    "Attendees" : "قاتناشقۇچىلار",
     "Close" : "ياپ",
     "Location" : "ئورنى",
     "Description" : "چۈشەندۈرۈش",
-    "Export" : "چىقار",
-    "Week" : "ھەپتە",
-    "Month" : "ئاي",
-    "Today" : "بۈگۈن",
-    "More" : "تېخىمۇ كۆپ",
-    "Edit" : "تەھرىر",
-    "Download" : "چۈشۈر",
-    "New Calendar" : "يېڭى يىلنامە",
-    "Name" : "ئاتى",
-    "Time" : "ۋاقىت",
-    "Repeat" : "قايتىلا",
-    "Add" : "قوش",
-    "New calendar" : "يېڭى يىلنامە"
+    "Play" : "چال"
 },
 "nplurals=1; plural=0;");
