@@ -23,6 +23,7 @@ declare(strict_types=1);
 namespace OCA\Calendar\Controller;
 
 use OCP\AppFramework\Controller;
+use OCP\AppFramework\Http\ContentSecurityPolicy;
 use OCP\AppFramework\Http\TemplateResponse;
 use OCP\IConfig;
 use OCP\IInitialStateService;
@@ -88,6 +89,7 @@ class PublicViewController extends Controller {
 	 *
 	 * @PublicPage
 	 * @NoCSRFRequired
+	 * @NoSameSiteCookieRequired
 	 *
 	 * @param string $token
 	 * @return TemplateResponse
@@ -96,6 +98,10 @@ class PublicViewController extends Controller {
 		$response = $this->publicIndex($token, 'base');
 		$response->addHeader('X-Frame-Options', 'ALLOW');
 
+		$csp = new ContentSecurityPolicy();
+		$csp->addAllowedFrameAncestorDomain('*');
+		$response->setContentSecurityPolicy($csp);
+
 		return $response;
 	}
 
